tempotools.integer_tempo_to_multiplier_tempo_pairs_report
=========================================================

.. autofunction:: abjad.tools.tempotools.integer_tempo_to_multiplier_tempo_pairs_report.integer_tempo_to_multiplier_tempo_pairs_report
